"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
from typing_extensions import TypedDict


class WorkflowsModelTypedDict(TypedDict):
    r"""All translations for given locale organized by workflow identifier"""


class WorkflowsModel(BaseModel):
    r"""All translations for given locale organized by workflow identifier"""


class LayoutsModelTypedDict(TypedDict):
    r"""All translations for given locale organized by layout identifier"""


class LayoutsModel(BaseModel):
    r"""All translations for given locale organized by layout identifier"""


class GetMasterJSONResponseDtoTypedDict(TypedDict):
    workflows: WorkflowsModelTypedDict
    r"""All translations for given locale organized by workflow identifier"""
    layouts: LayoutsModelTypedDict
    r"""All translations for given locale organized by layout identifier"""


class GetMasterJSONResponseDto(BaseModel):
    workflows: WorkflowsModel
    r"""All translations for given locale organized by workflow identifier"""

    layouts: LayoutsModel
    r"""All translations for given locale organized by layout identifier"""
