"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .uploadtranslationsrequestdto import (
    UploadTranslationsRequestDto,
    UploadTranslationsRequestDtoTypedDict,
)
from novu_py.types import BaseModel
from novu_py.utils import FieldMetadata, HeaderMetadata, RequestMetadata
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class TranslationControllerUploadTranslationFilesRequestTypedDict(TypedDict):
    upload_translations_request_dto: UploadTranslationsRequestDtoTypedDict
    r"""Translation files upload body details"""
    idempotency_key: NotRequired[str]
    r"""A header for idempotency purposes"""


class TranslationControllerUploadTranslationFilesRequest(BaseModel):
    upload_translations_request_dto: Annotated[
        UploadTranslationsRequestDto,
        FieldMetadata(request=RequestMetadata(media_type="multipart/form-data")),
    ]
    r"""Translation files upload body details"""

    idempotency_key: Annotated[
        Optional[str],
        pydantic.Field(alias="idempotency-key"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""A header for idempotency purposes"""
