"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class GetContextResponseDtoDataTypedDict(TypedDict):
    pass


class GetContextResponseDtoData(BaseModel):
    pass


class GetContextResponseDtoTypedDict(TypedDict):
    type: str
    id: str
    data: GetContextResponseDtoDataTypedDict
    created_at: str
    updated_at: str


class GetContextResponseDto(BaseModel):
    type: str

    id: str

    data: GetContextResponseDtoData

    created_at: Annotated[str, pydantic.Field(alias="createdAt")]

    updated_at: Annotated[str, pydantic.Field(alias="updatedAt")]
