"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .getenvironmenttagsdto import GetEnvironmentTagsDto, GetEnvironmentTagsDtoTypedDict
from novu_py.types import BaseModel
from novu_py.utils import FieldMetadata, HeaderMetadata, PathParamMetadata
import pydantic
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class EnvironmentsControllerGetEnvironmentTagsRequestTypedDict(TypedDict):
    environment_id: str
    r"""Environment internal ID (MongoDB ObjectId) or identifier"""
    idempotency_key: NotRequired[str]
    r"""A header for idempotency purposes"""


class EnvironmentsControllerGetEnvironmentTagsRequest(BaseModel):
    environment_id: Annotated[
        str,
        pydantic.Field(alias="environmentId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Environment internal ID (MongoDB ObjectId) or identifier"""

    idempotency_key: Annotated[
        Optional[str],
        pydantic.Field(alias="idempotency-key"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""A header for idempotency purposes"""


class EnvironmentsControllerGetEnvironmentTagsResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: List[GetEnvironmentTagsDtoTypedDict]


class EnvironmentsControllerGetEnvironmentTagsResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: List[GetEnvironmentTagsDto]
